@@ -1,4 +1,4 @@
-`skewness` <-
+skewness <-
 function(x) {
 x <- na.omit(x)
 n<-length(x)
@@ -7,4 +7,3 @@ suma<-sum((x-mean(x))^3)/s^3
 k <- n*suma/((n-1)*(n-2))
 return(k)
 }
-
